diff --git a/README.md b/README.md
index 29c94b804..1ead84bb8 100755
--- a/README.md
+++ b/README.md
@@ -54,6 +54,7 @@ List of Definitions
* [Chosen](http://harvesthq.github.com/chosen/) (by [Boris Yankov](https://github.com/borisyankov))
* [Chrome](http://developer.chrome.com/extensions/) (by [Matthew Kimber](https://github.com/matthewkimber))
* [Chrome App](http://developer.chrome.com/apps/) (by [Adam Lay](https://github.com/AdamLay))
+* [CKEditor](https://github.com/ckeditor/ckeditor-dev) (by [Ondrej Sevcik](https://github.com/ondrejsevcik))
* [CodeMirror](http://codemirror.net) (by [François de Campredon](https://github.com/fdecampredon))
* [Commander](http://github.com/visionmedia/commander.js) (by [Marcelo Dezem](https://github.com/mdezem))
* [Couchbase / Couchnode](https://github.com/couchbase/couchnode) (by [Basarat Ali Syed](https://github.com/basarat))
@@ -62,6 +63,7 @@ List of Definitions
* [d3.js](http://d3js.org/) (from TypeScript samples)
* [dhtmlxGantt](http://dhtmlx.com/docs/products/dhtmlxGantt) (by [Maksim Kozhukh](http://github.com/mkozhukh))
* [dhtmlxScheduler](http://dhtmlx.com/docs/products/dhtmlxScheduler) (by [Maksim Kozhukh](http://github.com/mkozhukh))
+* [Dock Spawn](http://dockspawn.com) (by [Drew Noakes](https://drewnoakes.com))
* [docCookies](https://developer.mozilla.org/en-US/docs/Web/API/document.cookie) (by [Jon Egerton](https://github.com/jonegerton))
* [domo](http://domo-js.com/) (by [Steve Fenton](https://github.com/Steve-Fenton))
* [doT](https://github.com/olado/doT) (by [ZombieHunter](https://github.com/ZombieHunter))
@@ -137,6 +139,7 @@ List of Definitions
* [jQuery.Cycle](http://jquery.malsup.com/cycle/) (by [François Guillot](http://fguillot.developpez.com/))
* [jQuery.Cycle2](http://jquery.malsup.com/cycle2/) (by [Donny Nadolny](https://github.com/dnadolny))
* [jQuery.dataTables](http://www.datatables.net) (by [Armin Sander](https://github.com/pragmatrix))
+* [jQuery.datetimepicker](http://trentrichardson.com/examples/timepicker/) (by [Doug McDonald](https://github.com/dougajmcdonald))
* [jQuery.dynatree](http://code.google.com/p/dynatree/) (by [François de Campredon](https://github.com/fdecampredon))
* [jQuery.Flot](http://www.flotcharts.org/) (by [Matt Burland](https://github.com/burlandm))
* [jQuery.form](http://malsup.com/jquery/form/) (by [François Guillot](http://fguillot.developpez.com/))
@@ -144,6 +147,7 @@ List of Definitions
* [jQuery.gridster](http://gridster.net) (by [Josh Baldwin](https://github.com/jbaldwin/gridster.d.ts))
* [jQuery.jNotify](http://jnotify.codeplex.com) (by [James Curran](https://github.com/jamescurran/))
* [jQuery.joyride](http://zurb.com/playground/jquery-joyride-feature-tour-plugin) (by [Vincent Bortone](https://github.com/vbortone))
+* [jQuery.jSignature] (https://github.com/willowsystems/jSignature) (by [Patrick Magee](https://github.com/pjmagee))
* [jQuery.noty](http://needim.github.io/noty/) (by [Aaron King](https://github.com/kingdango/))
* [jQuery.pickadate](https://github.com/amsul/pickadate.js) (by [Theodore Brown](https://github.com/theodorejb))
* [jQuery.payment](http://needim.github.io/noty/) (by [Eric J. Smith](https://github.com/ejsmith/))
@@ -155,6 +159,7 @@ List of Definitions
* [jQuery.Timer](http://jchavannes.com/jquery-timer/demo) (by [Joshua Strobl](https://github.com/JoshStrobl))
* [jQuery.TinyCarousel](http://baijs.nl/tinycarousel/) (by [Christiaan Rakowski](https://github.com/csrakowski))
* [jQuery.TinyScrollbar](http://baijs.nl/tinyscrollbar/) (by [Christiaan Rakowski](https://github.com/csrakowski))
+* [jQuery.tooltipster] (https://github.com/iamceege/tooltipster) (by [Patrick Magee](https://github.com/pjmagee))
* [jQuery.Transit](http://ricostacruz.com/jquery.transit/) (by [MrBigDog2U](https://github.com/MrBigDog2U))
* [jQuery.Validation](http://bassistance.de/jquery-plugins/jquery-plugin-validation/) (by [Boris Yankov](https://github.com/borisyankov))
* [jQuery.Watermark](http://jquery-watermark.googlecode.com) (by [Anwar Javed](https://github.com/anwarjaved))
@@ -238,7 +243,7 @@ List of Definitions
* [simple-cw-node](https://github.com/astronaughts/simple-cw-node) (by [vvakame](https://github.com/vvakame))
* [Sinon](http://sinonjs.org/) (by [William Sears](https://github.com/mrbigdog2u))
* [SlickGrid](https://github.com/mleibman/SlickGrid) (by [Josh Baldwin](https://github.com/jbaldwin))
-* [smoothie](https://github.com/joewalnes/smoothie) (by [Mike H. Hawley](https://github.com/mikehhawley))
+* [smoothie](https://github.com/joewalnes/smoothie) (by [Mike H. Hawley](https://github.com/mikehhawley) and [Drew Noakes](https://drewnoakes.com))
* [socket.io](http://socket.io) (by [William Orr](https://github.com/worr))
* [socket.io-client](http://socket.io) (by [Maido Kaara](https://github.com/v3rm0n))
* [SockJS](https://github.com/sockjs/sockjs-client) (by [Emil Ivanov](https://github.com/vladev))
@@ -264,6 +269,7 @@ List of Definitions
* [Underscore.js (Typed)](http://underscorejs.org/) (by [Josh Baldwin](https://github.com/jbaldwin/))
* [Underscore-ko.js](https://github.com/kamranayub/UnderscoreKO) (by [Maurits Elbers](https://github.com/MagicMau))
* [universal-analytics](https://github.com/peaksandpies/universal-analytics) (by [Bart van der Schoor](https://github.com/Bartvds))
+* [urlrouter](https://github.com/fengmk2/urlrouter) (by [Carlos Ballesteros Velasco](https://github.com/soywiz))
* [UUID.js](https://github.com/LiosK/UUID.js) (by [Jason Jarrett](https://github.com/staxmanade))
* [Valerie](https://github.com/davewatts/valerie) (by [Howard Richards](https://github.com/conficient))
* [Viewporter](https://github.com/zynga/viewporter) (by [Boris Yankov](https://github.com/borisyankov))
diff --git a/_infrastructure/tests/compile-runner.bat b/_infrastructure/tests/compile-runner.bat
index e54803ec8..49f737c5d 100644
--- a/_infrastructure/tests/compile-runner.bat
+++ b/_infrastructure/tests/compile-runner.bat
@@ -1 +1 @@
-tsc runner.ts --target ES5 --out runner.js --module commonjs
\ No newline at end of file
+tsc runner.ts --target ES5 --out runner.js --module commonjs --sourcemap
diff --git a/_infrastructure/tests/runner.js b/_infrastructure/tests/runner.js
index 649569923..9a3647abd 100644
--- a/_infrastructure/tests/runner.js
+++ b/_infrastructure/tests/runner.js
@@ -850,7 +850,7 @@ var DT;
var Promise = require('bluebird');
- var endDts = /\w\.ts$/i;
+ var endDts = /\w\.d\.ts$/i;
/////////////////////////////////
// .d.ts syntax inspection
@@ -1035,9 +1035,6 @@ var DT;
// add a closure to queue
this.queue.push(function () {
- // when activate, add test to active list
- _this.active.push(test);
-
// run it
var p = test.run();
p.then(defer.resolve.bind(defer), defer.reject.bind(defer));
@@ -1048,6 +1045,9 @@ var DT;
}
_this.step();
});
+
+ // return it
+ return test;
});
this.step();
@@ -1056,13 +1056,9 @@ var DT;
};
TestQueue.prototype.step = function () {
- var _this = this;
- // setTimeout to make it flush
- setTimeout(function () {
- while (_this.queue.length > 0 && _this.active.length < _this.concurrent) {
- _this.queue.pop().call(null);
- }
- }, 1);
+ while (this.queue.length > 0 && this.active.length < this.concurrent) {
+ this.active.push(this.queue.pop().call(null));
+ }
};
return TestQueue;
})();
@@ -1297,10 +1293,12 @@ var DT;
process.exit(0);
}
+ var testFull = process.env['TRAVIS_BRANCH'] ? /\w\/full$/.test(process.env['TRAVIS_BRANCH']) : false;
+
new TestRunner(dtPath, {
concurrent: argv['single-thread'] ? 1 : Math.max(cpuCores, 2),
tscVersion: argv['tsc-version'],
- testChanges: argv['test-changes'],
+ testChanges: testFull ? false : argv['test-changes'],
skipTests: argv['skip-tests'],
printFiles: argv['print-files'],
printRefMap: argv['print-refmap'],
@@ -1314,4 +1312,7 @@ var DT;
process.exit(2);
});
})(DT || (DT = {}));
+//grunt-start
+///
+//grunt-end
//# sourceMappingURL=runner.js.map
diff --git a/_infrastructure/tests/runner.ts b/_infrastructure/tests/runner.ts
index 6e71d621a..5d4f42815 100644
--- a/_infrastructure/tests/runner.ts
+++ b/_infrastructure/tests/runner.ts
@@ -75,8 +75,6 @@ module DT {
var defer = Promise.defer();
// add a closure to queue
this.queue.push(() => {
- // when activate, add test to active list
- this.active.push(test);
// run it
var p = test.run();
p.then(defer.resolve.bind(defer), defer.reject.bind(defer));
@@ -87,6 +85,8 @@ module DT {
}
this.step();
});
+ // return it
+ return test;
});
this.step();
// defer it
@@ -94,12 +94,9 @@ module DT {
}
private step(): void {
- // setTimeout to make it flush
- setTimeout(() => {
- while (this.queue.length > 0 && this.active.length < this.concurrent) {
- this.queue.pop().call(null);
- }
- }, 1);
+ while (this.queue.length > 0 && this.active.length < this.concurrent) {
+ this.active.push(this.queue.pop().call(null));
+ }
}
}
@@ -339,10 +336,12 @@ module DT {
process.exit(0);
}
+ var testFull = process.env['TRAVIS_BRANCH'] ? /\w\/full$/.test(process.env['TRAVIS_BRANCH']) : false;
+
new TestRunner(dtPath, {
concurrent: argv['single-thread'] ? 1 : Math.max(cpuCores, 2),
tscVersion: argv['tsc-version'],
- testChanges: argv['test-changes'],
+ testChanges: testFull ? false : argv['test-changes'], // allow magic branch
skipTests: argv['skip-tests'],
printFiles: argv['print-files'],
printRefMap: argv['print-refmap'],
diff --git a/_infrastructure/tests/src/suite/syntax.ts b/_infrastructure/tests/src/suite/syntax.ts
index 9211c3fde..915fd18d0 100644
--- a/_infrastructure/tests/src/suite/syntax.ts
+++ b/_infrastructure/tests/src/suite/syntax.ts
@@ -6,7 +6,7 @@ module DT {
var Promise: typeof Promise = require('bluebird');
- var endDts = /\w\.ts$/i;
+ var endDts = /\w\.d\.ts$/i;
/////////////////////////////////
// .d.ts syntax inspection
diff --git a/angularjs/angular-resource.d.ts b/angularjs/angular-resource.d.ts
index 0317e17b7..a0cd4ab85 100644
--- a/angularjs/angular-resource.d.ts
+++ b/angularjs/angular-resource.d.ts
@@ -51,6 +51,7 @@ declare module ng.resource {
// to be considered as parameters to the request.
// https://github.com/angular/angular.js/blob/v1.2.0/src/ngResource/resource.js#L461-L465
interface IResourceClass {
+ new(dataOrParams? : any) : T;
get(): T;
get(dataOrParams: any): T;
get(dataOrParams: any, success: Function): T;
diff --git a/angularjs/angular-route.d.ts b/angularjs/angular-route.d.ts
index b8d1db50b..628d746df 100644
--- a/angularjs/angular-route.d.ts
+++ b/angularjs/angular-route.d.ts
@@ -41,6 +41,7 @@ declare module ng.route {
resolve?: any;
redirectTo?: any;
reloadOnSearch?: boolean;
+ caseInsensitiveMatch?: boolean;
}
// see http://docs.angularjs.org/api/ng.$route#current
diff --git a/angularjs/angular-tests.ts b/angularjs/angular-tests.ts
index 4ce311698..8ab1efc72 100644
--- a/angularjs/angular-tests.ts
+++ b/angularjs/angular-tests.ts
@@ -94,6 +94,7 @@ module HttpAndRegularPromiseTests {
person: Person;
theAnswer: number;
letters: string[];
+ snack: string;
}
var someController: Function = ($scope: SomeControllerScope, $http: ng.IHttpService, $q: ng.IQService) => {
@@ -132,6 +133,12 @@ module HttpAndRegularPromiseTests {
cPromise.then((letters: string[]) => {
$scope.letters = letters;
});
+
+ // When $q.when is passed an IPromise, it returns an IPromise
+ var dPromise: ng.IPromise = $q.when($q.when("ALBATROSS!"));
+ dPromise.then((snack: string) => {
+ $scope.snack = snack;
+ });
}
// Test that we can pass around a type-checked success/error Promise Callback
diff --git a/angularjs/angular.d.ts b/angularjs/angular.d.ts
index b369a271f..4a9f12822 100755
--- a/angularjs/angular.d.ts
+++ b/angularjs/angular.d.ts
@@ -430,7 +430,7 @@ declare module ng {
// DocumentService
// see http://docs.angularjs.org/api/ng.$document
///////////////////////////////////////////////////////////////////////////
- interface IDocumentService extends Document {}
+ interface IDocumentService extends IAugmentedJQuery {}
///////////////////////////////////////////////////////////////////////////
// ExceptionHandlerService
@@ -455,6 +455,7 @@ declare module ng {
all(promises: {[id: string]: IPromise;}): IPromise<{[id: string]: any}>;
defer(): IDeferred;
reject(reason?: any): IPromise;
+ when(value: IPromise): IPromise;
when(value: T): IPromise;
}
diff --git a/async/async.d.ts b/async/async.d.ts
index 12aa4123f..68f2f192f 100644
--- a/async/async.d.ts
+++ b/async/async.d.ts
@@ -53,6 +53,8 @@ interface Async {
series(tasks: T, callback?: AsyncMultipleResultsCallback): void;
parallel(tasks: T[], callback?: AsyncMultipleResultsCallback): void;
parallel(tasks: T, callback?: AsyncMultipleResultsCallback): void;
+ parallelLimit(tasks: T[], limit: number, callback?: AsyncMultipleResultsCallback): void;
+ parallelLimit(tasks: T, limit: number, callback?: AsyncMultipleResultsCallback): void;
whilst(test: Function, fn: Function, callback: Function): void;
until(test: Function, fn: Function, callback: Function): void;
waterfall(tasks: T[], callback?: AsyncMultipleResultsCallback): void;
diff --git a/bluebird/bluebird-tests.ts b/bluebird/bluebird-tests.ts
index 14528b9b5..abead4237 100644
--- a/bluebird/bluebird-tests.ts
+++ b/bluebird/bluebird-tests.ts
@@ -1,319 +1,882 @@
///
-// Note: try to maintain the ordering and separators
+// Tests by: Bart van der Schoor
-var obj:Object;
-var bool:boolean;
-var num:number;
-var str:string;
-var x:any = null;
-var f:Function;
-var arr:any[];
-var exp:RegExp;
-var strArr:string[];
-var numArr:string[];
+// Note: replicate changes to all overloads in both definition and test file
+// Note: keep both static and instance members inline (so similar)
+// Note: try to maintain the ordering and separators, and keep to the pattern
-var value:any = null;
-var reason:any = null;
+var obj: Object;
+var bool: boolean;
+var num: number;
+var str: string;
+var err: Error;
+var x: any;
+var f: Function;
+var func: Function;
+var arr: any[];
+var exp: RegExp;
+var anyArr: any[];
+var strArr: string[];
+var numArr: number[];
-var promise:Promise;
-var p:Promise;
+// - - - - - - - - - - - - - - - - -
-var resolver:Promise.Resolver;
-var inspection:Promise.Inspection;
+var value: any;
+var reason: any;
+var insanity: any;
-// - - - - - - - - - - - - - - - - - - - - - - - -
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-var promise = new Promise((resolve:(value:any) => void, reject:(reason:any) => void) => {
- if(true) {
- resolve(123);
+interface Foo {
+ foo(): string;
+}
+interface Bar {
+ bar(): string;
+}
+
+// - - - - - - - - - - - - - - - - -
+
+interface StrFooMap {
+ [key:string]:Foo;
+}
+
+interface StrBarMap {
+ [key:string]:Bar;
+}
+
+// - - - - - - - - - - - - - - - - -
+
+interface StrFooArrMap {
+ [key:string]:Foo[];
+}
+
+interface StrBarArrMap {
+ [key:string]:Bar[];
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
+var foo: Foo;
+var bar: Bar;
+
+var fooArr: Foo[];
+var barArr: Bar[];
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
+var numProm: Promise;
+var strProm: Promise;
+var anyProm: Promise;
+var boolProm: Promise;
+var objProm: Promise
diff --git a/amcharts/AmCharts.d.ts b/amcharts/AmCharts.d.ts
index 9b29ef98f..97dd3a3ff 100644
--- a/amcharts/AmCharts.d.ts
+++ b/amcharts/AmCharts.d.ts
@@ -885,7 +885,9 @@ If you do not set properties such as dashLength, lineAlpha, lineColor, etc - val
/** AmChart is a base class of all charts. It can not be instantiated explicitly. AmCoordinateChart, AmPieChart and AmMap extend AmChart class. */
class AmChart {
- /** Background color. You should set backgroundAlpha to >0 value in order background to be visible. We recommend setting background color directly on a chart's DIV instead of using this property. #FFFFFF */
+ /** used when constructing a chart with a theme */
+ constructor(theme: any);
+ /** Background color. You should set backgroundAlpha to >0 value in order background to be visible. We recommend setting background color directly on a chart's DIV instead of using this property. #FFFFFF */
backgroundColor: string;
/** The chart creates AmBalloon class itself. If you want to customize balloon, get balloon instance using this property, and then change balloon's properties. AmBalloon */
balloon: AmBalloon;
@@ -943,7 +945,7 @@ If you do not set properties such as dashLength, lineAlpha, lineColor, etc - val
@param legend
@param legendDivId - Id of the legend div (optional).
*/
- addLegend(legend: AmLegend, legendDivId: string);
+ addLegend(legend: AmLegend, legendDivId?: string);
/** Adds a legend to the chart.
By default, you don't need to create div for your legend, however if you want it to be positioned in some different way, you can create div anywhere you want and pass id or reference to your div as a second parameter.
(NOTE: This method will not work on StockPanel.)
@@ -1437,7 +1439,7 @@ If you do not set properties such as dashLength, lineAlpha, lineColor, etc - val
chart.write("chartdiv");
*/
class AmSerialChart extends AmRectangularChart {
- /** Read-only. Chart creates category axis itself. If you want to change some properties, you should get this axis from the chart and set properties to this object. */
+ /** Read-only. Chart creates category axis itself. If you want to change some properties, you should get this axis from the chart and set properties to this object. */
categoryAxis: CategoryAxis;
/** Category field name tells the chart the name of the field in your dataProvider object which will be used for category axis values. */
categoryField: string;